@@ -47,7 +47,7 @@ class Response(abc.ABC):
     SC = [1, 2, 3] #: List of spacecraft indices.
     LINKS = [12, 23, 31, 13, 32, 21] #: List of link indices.
 
-    def __init__(self, orbits, orbit_interp_order=1, dt=0.3, size=259200, t0=0):
+    def __init__(self, orbits, orbit_interp_order=2, dt=0.3, size=259200, t0=0):
 
         self.git_url = 'https://gitlab.in2p3.fr/lisa-simulation/gw-response'
         self.version = importlib_metadata.version('lisagwresponse')
@@ -138,7 +138,8 @@ class Response(abc.ABC):
             ValueError: If ``tau`` lies outside of the orbit valid range (no extrapolation).
         """
         logger.info("Computing spline interpolation for TPS times")
-        interpolate = lambda t, data: InterpolatedUnivariateSpline(t, data, ext='raise')
+        interpolate = lambda t, data: InterpolatedUnivariateSpline(
+                t, data, k=self.orbit_interp_order, ext='raise')
 
         with h5py.File(self.orbits_path, 'r') as orbitf:
 
@@ -718,10 +719,12 @@ class GalacticBinary(ResponseFromStrain):
         phi0 (float): initial phase [rad]
         iota (float): inclination angle [rad]
         psi (float): polarization angle [rad]
+        tinit (float or 't0'): time at which the source is at the initial
+            frequency f and phase phi0 [s]. Defaults to 't0' to match ``t0``.
         **kwargs: all other args from :class:`lisagwrespons.ResponseFromStrain`
     """
 
-    def __init__(self, A, f, df=0, phi0=0, iota=0, psi=0, **kwargs):
+    def __init__(self, A, f, df=0, phi0=0, iota=0, psi=0, tinit='t0', **kwargs):
         super().__init__(**kwargs)
         self.A = float(A)
         self.f = float(f)
@@ -729,10 +732,14 @@ class GalacticBinary(ResponseFromStrain):
         self.phi0 = float(phi0)
         self.iota = float(iota)
         self.psi = float(psi)
+        if tinit == 't0':
+            self.tinit = self.t0
+        else:
+            self.tinit = float(tinit)
 
     def _write_metadata(self, hdf5, prefix=''):
         super()._write_metadata(hdf5, prefix)
-        self._write_attr(hdf5, prefix, 'A', 'f', 'df', 'phi0', 'iota', 'psi')
+        self._write_attr(hdf5, prefix, 'A', 'f', 'df', 'phi0', 'iota', 'psi', 'tinit')
 
     def compute_strain_in_source_frame(self, t):
         """Compute strain in the source frame.
@@ -744,7 +751,8 @@ class GalacticBinary(ResponseFromStrain):
             tuple: Couple of arrays ``(hplus, hcross)``, each of shape ``(len(t))``.
         """
         logger.info("Compute gravitational-wave strain in the source frame")
-        phase = pi * self.df * t**2 + 2 * pi * self.f * t - self.phi0
+        t_elapsed = t - self.tinit
+        phase = pi * self.df * t_elapsed**2 + 2 * pi * self.f * t_elapsed - self.phi0
         hplus = -self.A * (1 + cos(self.iota)**2) * cos(phase)
         hcross = -2 * self.A * cos(self.iota) * sin(phase)
         return (hplus, hcross)
